==> 0.1.1.tar.gz: autogui/quick_hotkey.py <==
from time import sleep
from subprocess import check_output

import keyboard as kb
import pyautogui as gui
import pygetwindow as getw

def _printer(func):
    def wrapper():
        print(func.__doc__, 'h_key performed')
        return func()
    return wrapper

def h_key():
    '''mentor list config'''
    gui.keyDown('shift')
    gui.press('tab', presses=9, interval=0.05)
    gui.keyUp('shift')
    sleep(0.5)
    gui.press('right', presses=1)

@_printer
def h_key2():
    '''op'''
    opfv = gui.getWindow('Form1')
    if opfv:  #  is None:
        opfv.maximize()
        opfv.restore()
        opfv.set_foreground()
    else:
        print('activate window Form1')

def h_key3():
    check_output(['start', 'c:/Users/conta1/git/Hello-World/omv/MyProjects/Win_gui/Mentor_gui.py'], shell=True)

def h_key4():
    check_output(['start', 'c:/Users/conta1/git/Hello-World/omv/MyProjects/Win_gui/Mentorgui_2.py'], shell=True)

@_printer
def h_key5():
    '''refacere jurnal'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 6, 0.05, 0.05)
        gui.press('return', 2, 0.05, 0.05)
    else:
        print('please activate Window LISTE')

@_printer
def h_key6():
    '''registru de casa'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 3, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('right', 1, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
    else:
        print('please activate Window LISTE')

@_printer
def h_key7():
    '''clienti datornici'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 4, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('right', 1, 0.05, 0.05)
        gui.press('down', 10, 0.05, 0.05)
        gui.press('return', 2, 0.05, 0.05)
    else:
        print('please activate Window LISTE')

@_printer
def h_key8():
    '''balanta de verificare'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 6, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('down', 1, 0.05, 0.05)
        gui.press('right', 1, 0.05, 0.05)
        gui.press('down', 6, 0.05, 0.05)
        gui.press('return', 2, 0.05, 0.05)
    else:
        print('please activate Window LISTE')

def h_key9():
    '''furnizori neachitati'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 4, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('down', 1, 0.05, 0.05)
        gui.press('right', 1, 0.05, 0.05)
        gui.press('down', 5, 0.05, 0.05)
        gui.press('return', 2, 0.05, 0.05)
    else:
        print('please activate Window LISTE')

def h_key10():
    '''furnizori neachitati valuta'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 4, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('down', 1, 0.05, 0.05)
        gui.press('right', 1, 0.05, 0.05)
        gui.press('down', 6, 0.05, 0.05)
        gui.press('return', 2, 0.05, 0.05)
    else:
        print('please activate Window LISTE')
        
@_printer
def h_key11():
    '''registru de banca'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 3, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('down', 4, 0.05, 0.05)
        gui.press('right', 1, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
    else:
        print('please activate Window LISTE')

@_printer
def h_key12():
    '''registru de banca'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 3, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('down', 6, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
    else:
        print('please activate Window LISTE')
    
# for i in gui.getWindows():
#     print(i)

kb.register_hotkey('alt+`', lambda: h_key2())
kb.register_hotkey('control+`', lambda: h_key5())
kb.register_hotkey('`+r', lambda: h_key6())
kb.register_hotkey('`+c', lambda: h_key7())
kb.register_hotkey('`+b', lambda: h_key8())
kb.register_hotkey('`+f', lambda: h_key9())
kb.register_hotkey('`+v+f', lambda: h_key10())
kb.register_hotkey('`+j+b', lambda: h_key11())
kb.register_hotkey('`+j+v', lambda: h_key12())
kb.wait()

==> 0.1.2.tar.gz: autogui/quick_hotkey.py <==
from time import sleep
from subprocess import check_output

import keyboard as kb
import pyautogui as gui
import pygetwindow as gw


def mv_mouse_right(x=1919, y=598):
    gui.moveTo(x, y)


def _printer(func):
    def wrapper():
        print(func.__doc__, 'h_key performed')
        return func()
    return wrapper


def h_key():
    '''mentor list config'''
    gui.keyDown('shift')
    gui.press('tab', presses=9, interval=0.05)
    gui.keyUp('shift')
    sleep(0.5)
    gui.press('right', presses=1)


@_printer
def h_key2():
    '''op'''
    opfv = gui.getWindow('Form1')
    if opfv:  # is None:
        opfv.maximize()
        opfv.restore()
        opfv.set_foreground()
    else:
        print('activate window Form1')

# def h_key3():
#     check_output(['start', 'c:/Users/conta1/git/Hello-World/omv/MyProjects/Win_gui/Mentor_gui.py'], shell=True)
# def h_key4():
#     check_output(['start', 'c:/Users/conta1/git/Hello-World/omv/MyProjects/Win_gui/Mentorgui_2.py'], shell=True)


@_printer
def h_key5():
    '''refacere jurnal'''
    # _date_ = gui.getWindow('LISTE - ')
    try:
        _date_ = gw.getWindowsWithTitle('LISTE - ')[0]
        mv_mouse_right()
        gui.press('f10')
        gui.press('right', 6, 0.05, 0.05)
        gui.press('return', 2, 0.05, 0.05)
    except IndexError:
        print('please activate Window LISTE')
#     if _date_:  #  is None:
#         #         gui.press('escape')
#         gui.press('f10')
#         gui.press('right', 6, 0.05, 0.05)
#         gui.press('return', 2, 0.05, 0.05)
#     else:
#         print('please activate Window LISTE')


@_printer
def h_key6():
    '''registru de casa'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 3, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('right', 1, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
    else:
        print('please activate Window LISTE')


@_printer
def h_key7():
    '''clienti datornici'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 4, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('right', 1, 0.05, 0.05)
        gui.press('down', 10, 0.05, 0.05)
        gui.press('return', 2, 0.05, 0.05)
    else:
        print('please activate Window LISTE')


@_printer
def h_key8():
    '''balanta de verificare'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 6, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('down', 1, 0.05, 0.05)
        gui.press('right', 1, 0.05, 0.05)
        gui.press('down', 6, 0.05, 0.05)
        gui.press('return', 2, 0.05, 0.05)
    else:
        print('please activate Window LISTE')


def h_key9():
    '''furnizori neachitati'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 4, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('down', 1, 0.05, 0.05)
        gui.press('right', 1, 0.05, 0.05)
        gui.press('down', 5, 0.05, 0.05)
        gui.press('return', 2, 0.05, 0.05)
    else:
        print('please activate Window LISTE')


def h_key10():
    '''furnizori neachitati valuta'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 4, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('down', 1, 0.05, 0.05)
        gui.press('right', 1, 0.05, 0.05)
        gui.press('down', 6, 0.05, 0.05)
        gui.press('return', 2, 0.05, 0.05)
    else:
        print('please activate Window LISTE')


@_printer
def h_key11():
    '''registru de banca'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 3, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('down', 4, 0.05, 0.05)
        gui.press('right', 1, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
    else:
        print('please activate Window LISTE')


@_printer
def h_key12():
    '''registru de banca'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 3, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('down', 6, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
    else:
        print('please activate Window LISTE')


@_printer
def h_key13():
    '''fisa de magazie'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 1, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('right', 1, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
    else:
        print('please activate Window LISTE')


@_printer
def h_key14():
    '''inventar centralizat'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 1, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('down', 8, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('down', 7, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
    else:
        print('please activate Window LISTE')


@_printer
def h_key15():
    '''stocuri pe gestiuni'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 1, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('down', 8, 0.05, 0.05)
        gui.press('return', 2, 0.05, 0.05)
        # gui.press('down', 7, 0.05, 0.05)
        # gui.press('return', 1, 0.05, 0.05)
    else:
        print('please activate Window LISTE')


@_printer
def h_key16():
    '''stocuri la terti'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 1, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('down', 12, 0.05, 0.05)
        gui.press('right', 1, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        # gui.press('down', 7, 0.05, 0.05)
        # gui.press('return', 1, 0.05, 0.05)
    else:
        print('please activate Window LISTE')


@_printer
def h_key17():
    '''lista fisa de cont'''
    _date_ = gui.getWindow('LISTE - ')
    if _date_:  #  is None:
        #         gui.press('escape')
        gui.press('f10')
        gui.press('right', 6, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        gui.press('down', 4, 0.05, 0.05)
        # gui.press('right', 1, 0.05, 0.05)
        gui.press('return', 1, 0.05, 0.05)
        # gui.press('down', 7, 0.05, 0.05)
        # gui.press('return', 1, 0.05, 0.05)
    else:
        print('please activate Window LISTE')

# for i in gui.getWindows():
#     print(i)


kb.register_hotkey('alt+`', lambda: h_key2())
kb.register_hotkey('control+`', lambda: h_key5())
kb.register_hotkey('`+r', lambda: h_key6())
kb.register_hotkey('`+c', lambda: h_key7())
kb.register_hotkey('`+b', lambda: h_key8())
kb.register_hotkey('`+f', lambda: h_key9())
kb.register_hotkey('`+v+f', lambda: h_key10())
kb.register_hotkey('`+j+b', lambda: h_key11())
kb.register_hotkey('`+j+v', lambda: h_key12())
kb.register_hotkey('`+s+m', lambda: h_key13())
kb.register_hotkey('`+s+c', lambda: h_key14())
kb.register_hotkey('`+s+g', lambda: h_key15())
kb.register_hotkey('`+s+t', lambda: h_key16())
kb.register_hotkey('`+d', lambda: h_key17())
kb.wait()
